From fe8dfd8ed20c0c95d34938d017d4be1d2c95f3f8 Mon Sep 17 00:00:00 2001
From: Noah Lavine <nlavine@haverford.edu>
Date: Sun, 18 Jul 2010 13:24:17 -0400
Subject: [PATCH 1/3] Explain objcode SCM

Add a comment to libguile/objcodes.c explaining the contents of the SCM
object that holds a struct scm_objcode.
---
 libguile/objcodes.c |   11 ++++++++++-
 1 files changed, 10 insertions(+), 1 deletions(-)

diff --git a/libguile/objcodes.c b/libguile/objcodes.c
index 2931468..eef676e 100644
--- a/libguile/objcodes.c
+++ b/libguile/objcodes.c
@@ -33,7 +33,9 @@
 #include "programs.h"
 #include "objcodes.h"
 
-/* SCM_OBJCODE_COOKIE is defined in _scm.h */
+/* SCM_OBJCODE_COOKIE is defined in _scm.h.
+ * it goes before objcode in the on-disk representation, but not
+ * in memory. */
 /* The length of the header must be a multiple of 8 bytes.  */
 verify (((sizeof (SCM_OBJCODE_COOKIE) - 1) & 7) == 0);
 
@@ -42,6 +44,13 @@ verify (((sizeof (SCM_OBJCODE_COOKIE) - 1) & 7) == 0);
  * Objcode type
  */
 
+/* an objcode SCM object is a four-word object containing
+   - scm_tc7_objcode | the flags for this objcode
+   - the struct scm_objcode C object
+   - the parent of this objcode, if this is a slice, or #f if none
+   - the file descriptor this objcode came from if this was mmaped, or 0 if none
+*/
+
 static SCM
 make_objcode_by_mmap (int fd)
 #define FUNC_NAME "make_objcode_by_mmap"
-- 
1.7.1

